import { CodepageMapping, CodepageType, QR_CODE_SYMBOLOGIES } from './const';
export * from './const';
interface Options {
    width: number;
    embedded: boolean;
    wordWrap: boolean;
    autoWrap: boolean;
    codepageMapping: CodepageMapping | Record<string, number>;
    imageMode: string;
    codepage: CodepageType | 'auto';
    codepageCandidates: string[];
}
interface BoxOptions {
    align: AlignType;
    style: 'single' | 'double';
    width: number;
    marginLeft: number;
    marginRight: number;
    paddingLeft: number;
    paddingRight: number;
}
type AlignType = 'left' | 'center' | 'right';
type SizeType = 'small' | 'normal';
type SymbologyType = keyof typeof QR_CODE_SYMBOLOGIES;
export type Size = 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8;
export type QrErrorLevelType = 'l' | 'm' | 'q' | 'h';
type CutType = 'full' | 'partial';
type StyleType = 'single' | 'double';
/**
 * Create a byte stream based on commands for ESC/POS printers
 */
export declare class EscPosEncoder {
    private _options;
    private _embedded;
    private _buffer;
    private _queued;
    private _cursor;
    private _codepage;
    private _state;
    /**
     * Create a new object
     *
     * @param  {object}   options   Object containing configuration options
     */
    constructor(options: Partial<Options>);
    /**
     * Reset the state of the object
     *
     * @param  {Options}   options   Object containing configuration options
     */
    private _reset;
    /**
     * Encode a string with the current code page
     *
     * @param  {string}   value  String to encode
     * @return {object}          Encoded string as a ArrayBuffer
     *
     */
    private _encode;
    /**
     * Add commands to the queue
     *
     * @param  {array}   value  Add array of numbers, arrays, buffers or Uint8Arrays to add to the buffer
     *
     */
    private _queue;
    /**
     * Flush current queue to the buffer
     *
     */
    private _flush;
    /**
     * Wrap the text while respecting the position of the cursor
     *
     * @param  {string}   value     String to wrap after the width of the paper has been reached
     * @param  {number}   position  Position on which to force a wrap
     * @return {array}              Array with each line
     */
    private _wrap;
    /**
     * Restore styles and codepages after drawing boxes or lines
     */
    private _restoreState;
    /**
     * Get code page identifier for the specified code page and mapping
     *
     * @param  {string}   codepage  Required code page
     * @return {number}             Identifier for the current printer according to the specified mapping
     */
    private _getCodepageIdentifier;
    /**
     * Initialize the printer
     *
     * @return {EscPosEncoder}          Return the object, for easy chaining commands
     *
     */
    initialize(): EscPosEncoder;
    /**
     * Change the code page
     *
     * @param  {CodepageType | 'auto'}   codepage  The codepage that we set the printer to
     * @return {EscPosEncoder}             Return the object, for easy chaining commands
     *
     */
    codepage(codepage: CodepageType | 'auto'): EscPosEncoder;
    /**
     * Print text
     *
     * @param  {string}   value  Text that needs to be printed
     * @param  {number}   wrap   Wrap text after this many positions
     * @return {EscPosEncoder}          Return the object, for easy chaining commands
     *
     */
    text(value: string, wrap?: number): EscPosEncoder;
    /**
     * Print a newline
     * @param count {int} - number of newlines to print, defaults to 1
     * @return {EscPosEncoder}          Return the object, for easy chaining commands
     *
     */
    newline(count?: number): EscPosEncoder;
    /**
     * Print text, followed by a newline
     *
     * @param  {string}   value  Text that needs to be printed
     * @param  {number}   wrap   Wrap text after this many positions
     * @return {EscPosEncoder}          Return the object, for easy chaining commands
     *
     */
    line(value: string, wrap?: number): EscPosEncoder;
    /**
     * Print text justified, followed by a newline
     *
     * @param  {string}   leftText  Left text
     * @param  {string}   rightText  Text that needs to be printed
     * @param  {Size}   charWidth  Width of the characters
     * @return {EscPosEncoder}          Return the object, for easy chaining commands
     *
     */
    lineJustified(leftText: string, rightText: string, charWidth?: Size): EscPosEncoder;
    /**
     * Encodes text line with special formatting characters (&c, &b)
     * @param line
     * @param wrap
     * @returns {EscPosEncoder}
     */
    lineFormatted(line: string, wrap?: boolean): EscPosEncoder;
    /**
     * Set left margin
     * @param units {number} - margin in horizontal motion units
     * @returns {EscPosEncoder}
     */
    marginLeft(units: number): EscPosEncoder;
    /**
     * Underline text
     *
     * @param  {boolean|number}   value  true to turn on underline, false to turn off, or 2 for double underline
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    underline(value: boolean | 2): EscPosEncoder;
    /**
     * Italic text
     *
     * @param  {boolean}          value  true to turn on italic, false to turn off, undefined to toggle
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    italic(value?: boolean): EscPosEncoder;
    /**
     * Bold text
     *
     * @param  {boolean}          value  true to turn on bold, false to turn off, undefined to toggle
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    bold(value?: boolean): EscPosEncoder;
    /**
     * Change width of text
     *
     * @param  {Size}          width    The width of the text, 1 - 8
     * @return {EscPosEncoder}                   Return the object, for easy chaining commands
     *
     */
    width(width: Size): EscPosEncoder;
    /**
     * Change height of text
     *
     * @param  {Size}          height  The height of the text, 1 - 8
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    height(height: Size): EscPosEncoder;
    /**
     * Invert text
     *
     * @param  {boolean}          value  true to turn on white text on black, false to turn off, undefined to toggle
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    invert(value?: boolean): EscPosEncoder;
    /**
     * Change text size
     *
     * @param  {string}          value   small or normal
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    size(value: SizeType): EscPosEncoder;
    /**
     * Change text alignment
     *
     * @param  {AlignType}          value   left, center or right
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    align(value: AlignType): EscPosEncoder;
    /**
     * Insert a table
     *
     * @param  {array}           columns  The column definitions
     * @param  {array}           data     Array containing rows. Each row is an array containing cells.
     *                                    Each cell can be a string value, or a callback function.
     *                                    The first parameter of the callback is the encoder object on
     *                                    which the function can call its methods.
     * @return {EscPosEncoder}                   Return the object, for easy chaining commands
     *
     */
    table(columns: Array<any>, data: Array<any>): EscPosEncoder;
    /**
     * Insert a horizontal rule
     *
     * @param  {object}          options  And object with the following properties:
     *                                    - style: The style of the line, either single or double
     *                                    - width: The width of the line, by default the width of the paper
     * @return {EscPosEncoder}                   Return the object, for easy chaining commands
     *
     */
    rule(options: {
        style: StyleType;
        width?: number;
    }): EscPosEncoder;
    /**
     * Insert a box
     *
     * @param  {object}           opts   And object with the following properties:
     *                                      - style: The style of the border, either single or double
     *                                      - width: The width of the box, by default the width of the paper
     *                                      - marginLeft: Space between the left border and the left edge
     *                                      - marginRight: Space between the right border and the right edge
     *                                      - paddingLeft: Space between the contents and the left border of the box
     *                                      - paddingRight: Space between the contents and the right border of the box
     * @param  {string|function}  contents  A string value, or a callback function.
     *                                      The first parameter of the callback is the encoder object on
     *                                      which the function can call its methods.
     * @return {EscPosEncoder}                     Return the object, for easy chaining commands
     *
     */
    box(opts: Partial<BoxOptions>, contents: string | ((enc: EscPosEncoder) => void)): EscPosEncoder;
    /**
     * Barcode
     *
     * @param  {string}           value  the value of the barcode
     * @param  {string}           symbology  the type of the barcode
     * @param  {number}           height  height of the barcode
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    barcode(value: string, symbology: SymbologyType, height: number): EscPosEncoder;
    /**
     * QR code
     *
     * @param  {string}           value  the value of the qr code
     * @param  {number}           model  model of the qrcode, either 1 or 2
     * @param  {Size}           size   size of the qrcode, a value between 1 and 8
     * @param  {QrErrorLevelType}           errorlevel  the amount of error correction used, either 'l', 'm', 'q', 'h'
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    qrcode(value: string, model: 1 | 2, size: Size, errorlevel: QrErrorLevelType): EscPosEncoder;
    /**
     * Cut paper
     *
     * @param  {string}          value   full or partial. When not specified a full cut will be assumed
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    cut(value?: CutType): EscPosEncoder;
    /**
     * Pulse
     *
     * @param  {number}          device  0 or 1 for on which pin the device is connected, default of 0
     * @param  {number}          on      Time the pulse is on in milliseconds, default of 100
     * @param  {number}          off     Time the pulse is off in milliseconds, default of 500
     * @return {EscPosEncoder}                  Return the object, for easy chaining commands
     *
     */
    pulse(device?: 0 | 1, on?: number, off?: number): EscPosEncoder;
    /**
     * Add raw printer commands
     *
     * @param  {array}           data   raw bytes to be included
     * @return {EscPosEncoder}          Return the object, for easy chaining commands
     *
     */
    raw(data: number[]): EscPosEncoder;
    /**
     * Encode all previous commands
     *
     * @return {Uint8Array}         Return the encoded bytes
     *
     */
    encode(): Uint8Array;
}
//# sourceMappingURL=index.d.ts.map